@@ -77,11 +77,17 @@ async def prepare_key(arr):
 
 
 async def encrypt_key(a, key):
-    return sum([aes_cbc_encrypt_a32(a[i:i + 4], key) async for i in range(0, len(a), 4)], [])
+    l = []
+    for i in range(0, len(a), 4):
+        l.append(await aes_cbc_encrypt_a32(a[i:i + 4], key))
+    return sum(l)
 
 
 async def decrypt_key(a, key):
-    return sum([aes_cbc_decrypt_a32(a[i:i + 4], key) async for i in range(0, len(a), 4)])
+    l = []
+    for i in range(0, len(a), 4):
+        l.append(await aes_cbc_decrypt_a32(a[i:i + 4], key))
+    return sum(l)
 
 
 async def encrypt_attr(attr, key):
