@@ -86,11 +86,12 @@ class Mega:
             'a':
             'up',
             'k':
-            await a32_to_base64(await encrypt_key(master_key, password_key)),
+            (await a32_to_base64((await encrypt_key(master_key, password_key)))),
             'ts':
-            await base64_url_encode(
-                await a32_to_str(session_self_challenge) +
-                await a32_to_str(await encrypt_key(session_self_challenge, master_key)))
+            (await base64_url_encode((
+                (await a32_to_str(session_self_challenge)) +
+                (await a32_to_str((await encrypt_key(session_self_challenge, master_key))))
+            )))
         })
 
         resp = await self._api_request({'a': 'us', 'user': user})
